@@ -1,6 +1,7 @@
+import unittest
+
 import numpy as np
 import numpy.testing as npt
-import unittest
 import wisdem.drivetrainse.generator_models as gm
 
 
@@ -417,4 +418,9 @@ def suite():
 
 
 if __name__ == "__main__":
-    unittest.TextTestRunner().run(suite())
+    result = unittest.TextTestRunner().run(suite())
+
+    if result.wasSuccessful():
+        exit(0)
+    else:
+        exit(1)
